==> dwarf_debugger-1.0.2.tar.gz: dwarf_debugger-1.0.2/README.md <==
# Dwarf

[![PyPI pyversions](https://img.shields.io/pypi/pyversions/dwarf_debugger.svg)](https://pypi.python.org/pypi/dwarf_debugger/)
[![PyPI version shields.io](https://img.shields.io/pypi/v/dwarf_debugger.svg)](https://pypi.python.org/pypi/dwarf_debugger/)
[![GitHub license](https://img.shields.io/github/license/iGio90/Dwarf.svg)](https://github.com/iGio90/Dwarf/blob/master/LICENSE)
[![GitHub issues](https://img.shields.io/github/issues/iGio90/Dwarf.svg)](https://GitHub.com/iGio90/Dwarf/issues/)

A debugger for reverse engineers, crackers and security analyst.
Or you can call it damn, why are raspberries so fluffy or yet, duck warriors are rich as fuck. Whatever you like!
Built on top of pyqt5, frida and some terrible code.

### Installation
```
pip3 install dwarf-debugger
```
Development
```
pip3 install https://github.com/iGio90/Dwarf/archive/master.zip
```

<p align="center">
  <br>
  <img src="dwarf_debugger/assets/dwarf.png">
  <br>
  <br>
  <br>
  <a href="http://www.giovanni-rocca.com/dwarf/">What is Dwarf</a> |
  <a href="http://www.giovanni-rocca.com/dwarf/features/">Features</a> |
  <a href="http://www.giovanni-rocca.com/dwarf/setup/">Setup</a> |
  <a href="https://igio90.github.io/Dwarf/">Javascript</a> |
  <a href="http://www.giovanni-rocca.com/dwarf/tutorials/">Tutorials</a> |
  <a href="http://www.giovanni-rocca.com/dwarf/screenshots/">Screenshots</a> |
  <a href="https://github.com/iGio90/Dwarf/blob/master/LICENSE">License</a> |
  <a href="https://join.slack.com/t/resecret/shared_invite/enQtMzc1NTg4MzE3NjA1LTlkNzYxNTIwYTc2ZTYyOWY1MTQ1NzBiN2ZhYjQwYmY0ZmRhODQ0NDE3NmRmZjFiMmE1MDYwNWJlNDVjZDcwNGE">Slack</a>
  <br>
  <br>
</p>

==> dwarf_debugger-1.0.5.tar.gz: dwarf_debugger-1.0.5/README.md <==
# Dwarf

[![PyPI pyversions](https://img.shields.io/pypi/pyversions/dwarf_debugger.svg)](https://pypi.python.org/pypi/dwarf_debugger/)
[![PyPI version shields.io](https://img.shields.io/pypi/v/dwarf_debugger.svg)](https://pypi.python.org/pypi/dwarf_debugger/)
[![GitHub license](https://img.shields.io/github/license/iGio90/Dwarf.svg)](https://github.com/iGio90/Dwarf/blob/master/LICENSE)
[![GitHub issues](https://img.shields.io/github/issues/iGio90/Dwarf.svg)](https://GitHub.com/iGio90/Dwarf/issues/)

A debugger for reverse engineers, crackers and security analyst.
Or you can call it damn, why are raspberries so fluffy or yet, duck warriors are rich as fuck. Whatever you like!
Built on top of pyqt5, frida and some terrible code.

### Known Issues
+ JavaTraceView is distorted
+ JavaTraceView shows weakref/handle instead of value

We are working on Dwarf 2.0 release


### Installation
```
pip3 install dwarf-debugger
```
Development
```
pip3 install https://github.com/iGio90/Dwarf/archive/master.zip
```

<p align="center">
  <br>
  <img src="dwarf_debugger/assets/dwarf.png">
  <br>
  <br>
  <br>
  <a href="http://www.giovanni-rocca.com/dwarf/">What is Dwarf</a> |
  <a href="http://www.giovanni-rocca.com/dwarf/features/">Features</a> |
  <a href="http://www.giovanni-rocca.com/dwarf/setup/">Setup</a> |
  <a href="https://igio90.github.io/Dwarf/">Javascript</a> |
  <a href="http://www.giovanni-rocca.com/dwarf/tutorials/">Tutorials</a> |
  <a href="http://www.giovanni-rocca.com/dwarf/screenshots/">Screenshots</a> |
  <a href="https://github.com/iGio90/Dwarf/blob/master/LICENSE">License</a> |
  <a href="https://join.slack.com/t/resecret/shared_invite/enQtMzc1NTg4MzE3NjA1LTlkNzYxNTIwYTc2ZTYyOWY1MTQ1NzBiN2ZhYjQwYmY0ZmRhODQ0NDE3NmRmZjFiMmE1MDYwNWJlNDVjZDcwNGE">Slack</a>
  <br>
  <br>
</p>
